==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/oauth2/l10n/bg.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Вашият клиент не е упълномощен да се свързва. Моля, информирайте администратора на вашия клиент.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Вашият URL за пренасочване трябва да е пълен URL, например: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Позволява удостоверяване от други уеб приложения, съвместими с OAuth2 .",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Приложението OAuth2 позволява на администраторите да конфигурират вградения работен поток за удостоверяване, за да позволят и удостоверяване от други уеб приложения, съвместими с OAuth2 .",
    "OAuth 2.0 clients" : "OAuth 2.0 клиенти",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 позволява на външни услуги да изискват достъп до {instanceName}.",
    "Name" : "Име",
    "Redirection URI" : "URI за пренасочване",
    "Client Identifier" : "Идентификатор на клиента",
    "Secret key" : "Секретен ключ",
    "Add client" : "Добавяне на клиент",
    "Add" : "Добавяне",
    "Show client secret" : "Покажете тайната на клиента",
    "Delete" : "Изтриване"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/oauth2/l10n/bg.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Вашият клиент не е упълномощен да се свързва. Моля, информирайте администратора на вашия клиент.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Вашият URL за пренасочване трябва да е пълен URL, например: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Позволява удостоверяване от други уеб приложения, съвместими с OAuth2 .",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Приложението OAuth2 позволява на администраторите да конфигурират вградения работен поток за удостоверяване, за да позволят и удостоверяване от други уеб приложения, съвместими с OAuth2 .",
    "Secret key" : "Секретен ключ",
    "Delete" : "Изтриване",
    "OAuth 2.0 clients" : "OAuth 2.0 клиенти",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 позволява на външни услуги да изискват достъп до {instanceName}.",
    "Name" : "Име",
    "Redirection URI" : "URI за пренасочване",
    "Add client" : "Добавяне на клиент",
    "Add" : "Добавяне",
    "Client Identifier" : "Идентификатор на клиента",
    "Show client secret" : "Покажете тайната на клиента"
},
"nplurals=2; plural=(n != 1);");
